svn commit: r225009 - head/sys/dev/coretemp

Attilio Rao attilio at FreeBSD.org
Fri Aug 19 13:31:48 UTC 2011


Author: attilio
Date: Fri Aug 19 13:31:48 2011
New Revision: 225009
URL: http://svn.freebsd.org/changeset/base/225009

Log:
  Bump the maximum coretemp limit (for CPU temperature) to 110. Several
  cores with temp in the range 101-105 have been found in the past.
  
  Sponsored by:	Sandvine Incorporated
  Reviewed by:	delphij, emaste
  Approved by:	re (kib)
  MFC after:	3 days

Modified:
  head/sys/dev/coretemp/coretemp.c

Modified: head/sys/dev/coretemp/coretemp.c
==============================================================================
--- head/sys/dev/coretemp/coretemp.c	Fri Aug 19 12:55:50 2011	(r225008)
+++ head/sys/dev/coretemp/coretemp.c	Fri Aug 19 13:31:48 2011	(r225009)
@@ -225,12 +225,12 @@ coretemp_attach(device_t dev)
 			 * these numbers are, with the publicly available
 			 * documents from Intel.
 			 *
 			 * For now, we consider [70, 100]C range, as
 			 * described in #322683, as "reasonable" and accept
 			 * these values whenever the MSR is available for
 			 * read, regardless the CPU model.
 			 */
-			if (tjtarget >= 70 && tjtarget <= 100)
+			if (tjtarget >= 70 && tjtarget <= 110)
 				sc->sc_tjmax = tjtarget;
 			else
 				device_printf(dev, "Tj(target) value %d "
@@ -225,12 +225,12 @@ coretemp_attach(device_t dev)
 			 * documents from Intel.
 			 *
-			 * For now, we consider [70, 100]C range, as
+			 * For now, we consider [70, 110]C range, as
 			 * described in #322683, as "reasonable" and accept
 			 * these values whenever the MSR is available for


More information about the svn-src-all mailing list